const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const CleanWebpackPlugin = require('clean-webpack-plugin');

const settings = {
    distPath: path.join(__dirname,"dist"),
    srcPath: path.join(__dirname, "src")
}

function srcPathExtend(subPath)
{
    return path.join(settings.srcPath, subPath);
}
const isDevMode = true;
module.exports = 
{
    resolve: 
    {
        extensions: [".ts", ".tsx", ".js"],
    },
    entry : './src/index.tsx',
    output : {
        path : path.join(__dirname, '/dist'),
        filename: 'index.bundle.js' 
    },
    // externals :
    // {
    //     'react' : 'React'
    // },
    // module : {
    //     rules : [
    //         {
    //             test : /\.js$/,
    //             exclude : /node_modules/,
    //             use : {
    //                 loader : 'babel-loader'
    //             }
    //         }
    //     ]
    // },
    module: {
        rules: [
            {
                test: /\.tsx?$/,
                use: ["babel-loader", "ts-loader", "tslint-loader"]
            },
            {
             test : /\.js$/,
             exclude : /node_modules/,
             use : 
                {
                     loader : 'babel-loader'
                }
            },
            {
                test: /\.scss$/,
                use: [
                    "style-loader",
                    {
                        loader: "css-loader",
                        options: {
                            sourceMap: isDevMode
                        }
                    },
                    {
                        loader: "postcss-loader",
                        options: {
                            plugins: [
                                require("autoprefixer")()
                            ],
                            sourceMap: isDevMode
                        }
                    },
                    {
                        loader: "sass-loader",
                        options: {
                            sourceMap: isDevMode
                        }
                    }
                ]
            },
            {
                test: /\.(ttf|eot|woff|woff2)$/,
                use: {
                    loader: "file-loader",
                    options: {
                        name: "fonts/[name].[ext]",
                    },
                },
            },
            {
                test: /\.(jpe?g|png|gif|svg|ico)$/i,
                use: [
                    {
                        loader: "file-loader",
                        options: {
                            outputPath: "assets/"
                        }
                    }
                ]
            }
        ]
    },
    plugins :[
        new HtmlWebpackPlugin({
            template : './src/index.html'   
        })
    ]
}